/* Generated by wayland-scanner 1.25.0 */

#ifndef FIFO_V1_ENUM_PROTOCOL_H
#define FIFO_V1_ENUM_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#ifndef WP_FIFO_MANAGER_V1_ERROR_ENUM
#define WP_FIFO_MANAGER_V1_ERROR_ENUM
/**
 * @ingroup iface_wp_fifo_manager_v1
 * fatal presentation error
 *
 * These fatal protocol errors may be emitted in response to
 * illegal requests.
 */
enum wp_fifo_manager_v1_error {
	/**
	 * fifo manager already exists for surface
	 */
	WP_FIFO_MANAGER_V1_ERROR_ALREADY_EXISTS = 0,
};
#endif /* WP_FIFO_MANAGER_V1_ERROR_ENUM */

#ifndef WP_FIFO_V1_ERROR_ENUM
#define WP_FIFO_V1_ERROR_ENUM
/**
 * @ingroup iface_wp_fifo_v1
 * fatal error
 *
 * These fatal protocol errors may be emitted in response to
 * illegal requests.
 */
enum wp_fifo_v1_error {
	/**
	 * the associated surface no longer exists
	 */
	WP_FIFO_V1_ERROR_SURFACE_DESTROYED = 0,
};
#endif /* WP_FIFO_V1_ERROR_ENUM */

#ifdef  __cplusplus
}
#endif

#endif
