/* Generated by wayland-scanner 1.25.0 */

#ifndef XDG_SESSION_MANAGEMENT_V1_ENUM_PROTOCOL_H
#define XDG_SESSION_MANAGEMENT_V1_ENUM_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#ifndef XDG_SESSION_MANAGER_V1_ERROR_ENUM
#define XDG_SESSION_MANAGER_V1_ERROR_ENUM
enum xdg_session_manager_v1_error {
	/**
	 * a requested session is already in use
	 */
	XDG_SESSION_MANAGER_V1_ERROR_IN_USE = 1,
	/**
	 * invalid session identifier
	 */
	XDG_SESSION_MANAGER_V1_ERROR_INVALID_SESSION_ID = 2,
	/**
	 * invalid reason
	 */
	XDG_SESSION_MANAGER_V1_ERROR_INVALID_REASON = 3,
};
#endif /* XDG_SESSION_MANAGER_V1_ERROR_ENUM */

#ifndef XDG_SESSION_MANAGER_V1_REASON_ENUM
#define XDG_SESSION_MANAGER_V1_REASON_ENUM
/**
 * @ingroup iface_xdg_session_manager_v1
 * reason for getting a session
 *
 * The reason may determine in what way a session restores the window
 * management state of associated toplevels.
 *
 * For example newly launched applications might be launched on the active
 * workspace with restored size and position, while a recovered
 * application might restore additional state such as active workspace and
 * stacking order.
 */
enum xdg_session_manager_v1_reason {
	/**
	 * an app is newly launched
	 *
	 * A new app instance is launched, for example from an app
	 * launcher.
	 */
	XDG_SESSION_MANAGER_V1_REASON_LAUNCH = 1,
	/**
	 * an app recovered
	 *
	 * A app instance is recovering from for example a compositor or
	 * app crash.
	 */
	XDG_SESSION_MANAGER_V1_REASON_RECOVER = 2,
	/**
	 * an app restored
	 *
	 * A app instance is restored, for example part of a restored
	 * session, or restored from having been temporarily terminated due
	 * to resource constraints.
	 */
	XDG_SESSION_MANAGER_V1_REASON_SESSION_RESTORE = 3,
};
#endif /* XDG_SESSION_MANAGER_V1_REASON_ENUM */

#ifndef XDG_SESSION_V1_ERROR_ENUM
#define XDG_SESSION_V1_ERROR_ENUM
enum xdg_session_v1_error {
	/**
	 * toplevel name is already in use
	 */
	XDG_SESSION_V1_ERROR_NAME_IN_USE = 1,
	/**
	 * toplevel was already mapped when restored
	 */
	XDG_SESSION_V1_ERROR_ALREADY_MAPPED = 2,
	/**
	 * provided toplevel name is invalid
	 */
	XDG_SESSION_V1_ERROR_INVALID_NAME = 3,
	/**
	 * toplevel already added
	 */
	XDG_SESSION_V1_ERROR_ALREADY_ADDED = 4,
};
#endif /* XDG_SESSION_V1_ERROR_ENUM */

#ifdef  __cplusplus
}
#endif

#endif
