/* Generated by wayland-scanner 1.25.0 */

#ifndef XX_CUTOUTS_UNSTABLE_V1_ENUM_PROTOCOL_H
#define XX_CUTOUTS_UNSTABLE_V1_ENUM_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#ifndef XX_CUTOUTS_MANAGER_V1_ERROR_ENUM
#define XX_CUTOUTS_MANAGER_V1_ERROR_ENUM
enum xx_cutouts_manager_v1_error {
	/**
	 * given wl_surface has incorrect role
	 */
	XX_CUTOUTS_MANAGER_V1_ERROR_INVALID_ROLE = 0,
	/**
	 * wl_surface or surface role was destroyed before the cutouts object
	 */
	XX_CUTOUTS_MANAGER_V1_ERROR_DEFUNCT_CUTOUTS_OBJECT = 1,
};
#endif /* XX_CUTOUTS_MANAGER_V1_ERROR_ENUM */

#ifndef XX_CUTOUTS_V1_TYPE_ENUM
#define XX_CUTOUTS_V1_TYPE_ENUM
/**
 * @ingroup iface_xx_cutouts_v1
 * Cutout type
 *
 * These values indicate the type of cutout. The information is
 * meant to help clients to decide whether they can possibly
 * ignore the element.
 */
enum xx_cutouts_v1_type {
	/**
	 * A generic cutout
	 *
	 * This element type can be used by the compositor if it doesn't
	 * want to provide a more specific type.
	 */
	XX_CUTOUTS_V1_TYPE_CUTOUT = 0,
	/**
	 * Small functional cutout area
	 *
	 * A functional, irregular shape on one of the device's edges. It
	 * often contains a camera.
	 */
	XX_CUTOUTS_V1_TYPE_NOTCH = 1,
	/**
	 * A curved display edge
	 *
	 * A curved display edge intended to make the device appear like
	 * not having any bezel.
	 */
	XX_CUTOUTS_V1_TYPE_WATERFALL = 2,
};
#endif /* XX_CUTOUTS_V1_TYPE_ENUM */

#ifndef XX_CUTOUTS_V1_CORNER_POSITION_ENUM
#define XX_CUTOUTS_V1_CORNER_POSITION_ENUM
/**
 * @ingroup iface_xx_cutouts_v1
 * Corner position
 *
 * The position of a corner on a surface
 */
enum xx_cutouts_v1_corner_position {
	XX_CUTOUTS_V1_CORNER_POSITION_TOP_LEFT = 0,
	XX_CUTOUTS_V1_CORNER_POSITION_TOP_RIGHT = 1,
	XX_CUTOUTS_V1_CORNER_POSITION_BOTTOM_RIGHT = 2,
	XX_CUTOUTS_V1_CORNER_POSITION_BOTTOM_LEFT = 3,
};
#endif /* XX_CUTOUTS_V1_CORNER_POSITION_ENUM */

#ifndef XX_CUTOUTS_V1_ERROR_ENUM
#define XX_CUTOUTS_V1_ERROR_ENUM
enum xx_cutouts_v1_error {
	/**
	 * Invalid element id in a set_unhandled request
	 */
	XX_CUTOUTS_V1_ERROR_INVALID_ELEMENT_ID = 0,
};
#endif /* XX_CUTOUTS_V1_ERROR_ENUM */

#ifdef  __cplusplus
}
#endif

#endif
