/* Generated by wayland-scanner 1.25.0 */

#ifndef XX_ZONES_V1_ENUM_PROTOCOL_H
#define XX_ZONES_V1_ENUM_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#ifndef XX_ZONE_V1_ERROR_ENUM
#define XX_ZONE_V1_ERROR_ENUM
enum xx_zone_v1_error {
	/**
	 * an invalid value has been submitted
	 */
	XX_ZONE_V1_ERROR_INVALID = 0,
};
#endif /* XX_ZONE_V1_ERROR_ENUM */

#ifdef  __cplusplus
}
#endif

#endif
